==> unit-1.0.31-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTasksListCatalog.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTasksListCatalog<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public TasksList tasksList;
	public TaskComments taskComments;
	public TasksListCatalog.TaskComments. _61_2_1582985367 _61_2_1582985367;
	public TasksListCatalog.TaskComments. Comments comments;

    public AbstractTasksListCatalog(B box) {
        super(box);
        id("tasksListCatalog");
    }

    @Override
	public void init() {
		super.init();
		if (tasksList == null) tasksList = register(new TasksList(box()).<TasksList>id("a2103281753").owner(AbstractTasksListCatalog.this));
		if (taskComments == null) taskComments = register(new TaskComments(box()).<TaskComments>id("a_1355199380").owner(AbstractTasksListCatalog.this));
		if (taskComments != null) _61_2_1582985367 = taskComments._61_2_1582985367;
		if (taskComments != null) comments = taskComments.comments;
	}

	public class TasksList extends io.intino.alexandria.ui.displays.components.List<B, TasksListItem, org.monet.space.kernel.model.Task> implements io.intino.alexandria.ui.displays.components.collection.Selectable {

		public TasksList(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
		}
		public void onSelect(io.intino.alexandria.ui.displays.events.SelectionListener listener) {
			super.addSelectionListener(listener);
		}
		public TasksListItem create(org.monet.space.kernel.model.Task element) {
			TasksListItem result = new TasksListItem((UnitBox)box());
			result.id(java.util.UUID.randomUUID().toString());
			result.item(element);
			return result;
		}
	}

	public class TaskComments extends io.intino.alexandria.ui.displays.components.BlockPopover<io.intino.alexandria.ui.displays.notifiers.BlockPopoverNotifier, B>  {
		public TasksListCatalog.TaskComments. _61_2_1582985367 _61_2_1582985367;
		public TasksListCatalog.TaskComments. Comments comments;

		public TaskComments(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_61_2_1582985367 == null) _61_2_1582985367 = register(new _61_2_1582985367(box()).<_61_2_1582985367>id("a_980442751").owner(AbstractTasksListCatalog.this));
			if (comments == null) comments = register(new Comments(box()).<Comments>id("a519371879").owner(AbstractTasksListCatalog.this));
		}

		public class _61_2_1582985367 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _61_2_1582985367(B box) {
				super(box);
				_value("Más información");
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Comments extends io.intino.alexandria.ui.displays.components.HtmlViewer<io.intino.alexandria.ui.displays.notifiers.HtmlViewerNotifier, B>  {

			public Comments(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.7-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractTasksListCatalog.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractTasksListCatalog<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public TasksList tasksList;
	public TaskComments taskComments;
	public TasksListCatalog.TaskComments. _61_2_1582985367 _61_2_1582985367;
	public TasksListCatalog.TaskComments. Comments comments;

    public AbstractTasksListCatalog(B box) {
        super(box);
        id("tasksListCatalog");
    }

    @Override
	public void init() {
		super.init();
		if (tasksList == null) tasksList = register(new TasksList(box()).<TasksList>id("a2103281753").owner(AbstractTasksListCatalog.this));
		if (taskComments == null) taskComments = register(new TaskComments(box()).<TaskComments>id("a_1355199380").owner(AbstractTasksListCatalog.this));
		if (taskComments != null) _61_2_1582985367 = taskComments._61_2_1582985367;
		if (taskComments != null) comments = taskComments.comments;
	}

    @Override
    public void remove() {
        super.remove();
	    if (tasksList != null) tasksList.unregister();
	    if (taskComments != null) taskComments.unregister();
	}

	public class TasksList extends io.intino.alexandria.ui.displays.components.List<B, TasksListItem, org.monet.space.kernel.model.Task> implements io.intino.alexandria.ui.displays.components.collection.Selectable {

		public TasksList(B box) {
			super(box);

			_pageSize(20);
		}

		@Override
		public void init() {
			super.init();
		}

		@Override
		public void unregister() {
		    super.unregister();
		}
		public void onSelect(io.intino.alexandria.ui.displays.events.SelectionListener listener) {
			super.addSelectionListener(listener);
		}
		public TasksListItem create(org.monet.space.kernel.model.Task element) {
			TasksListItem result = new TasksListItem((UnitBox)box());
			result.id(java.util.UUID.randomUUID().toString());
			result.item(element);
			return result;
		}
	}

	public class TaskComments extends io.intino.alexandria.ui.displays.components.BlockPopover<io.intino.alexandria.ui.displays.notifiers.BlockPopoverNotifier, B>  {
		public TasksListCatalog.TaskComments. _61_2_1582985367 _61_2_1582985367;
		public TasksListCatalog.TaskComments. Comments comments;

		public TaskComments(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_61_2_1582985367 == null) _61_2_1582985367 = register(new _61_2_1582985367(box()).<_61_2_1582985367>id("a_980442751").owner(AbstractTasksListCatalog.this));
			if (comments == null) comments = register(new Comments(box()).<Comments>id("a519371879").owner(AbstractTasksListCatalog.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_61_2_1582985367 != null) _61_2_1582985367.unregister();
			if (comments != null) comments.unregister();
		}

		public class _61_2_1582985367 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public _61_2_1582985367(B box) {
				super(box);
				_value("Más información");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class Comments extends io.intino.alexandria.ui.displays.components.HtmlViewer<io.intino.alexandria.ui.displays.notifiers.HtmlViewerNotifier, B>  {

			public Comments(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
